@@ -16,6 +16,7 @@ kml_layer.SpatialPixels <- function(
   TimeSpan.begin,
   TimeSpan.end,
   layer.name,
+  png.type = "cairo-png",
   ...
   ){
 
@@ -104,7 +105,7 @@ kml_layer.SpatialPixels <- function(
      png.height <- round(min.png.width*png.height/png.width)
      png.width <- min.png.width  
   }
-  png(filename = raster_name, bg = "transparent", type = "cairo-png", width = png.width, height = png.height)
+  png(filename = raster_name, bg = "transparent", type = png.type, width = png.width, height = png.height)
   par(mar = c(0, 0, 0, 0), xaxs = "i", yaxs = "i")
   if(!is.na(charmatch("z.lim", names(call.lst)))){ 
     z.lim <- eval(call.lst[["z.lim"]]) 
